﻿''' <summary>
''' Represents a TCP port entry.
''' </summary>
''' <remarks>Objects of this class are used by the TCP port collector. They
''' represent a server TCP facility that will be scanned for availability.
''' </remarks>
Public Class TCPPortEntry

    ''' <summary>
    ''' Server and service friendly name.
    ''' </summary>
    ''' <remarks></remarks>
    Protected m_name As String

    ''' <summary>
    ''' Server host name or address.
    ''' </summary>
    ''' <remarks></remarks>
    Protected m_address As String

    ''' <summary>
    ''' Server port.
    ''' </summary>
    ''' <remarks></remarks>
    Protected m_port As Integer

    ''' <summary>
    ''' Get/set the server and service friendly name.
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Name() As String
        Get
            Return m_name
        End Get
        Set(ByVal value As String)
            m_name = value
        End Set
    End Property

    ''' <summary>
    ''' Get/set the server host name or address.
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Address() As String
        Get
            Return m_address
        End Get
        Set(ByVal value As String)
            m_address = value
        End Set
    End Property

    ''' <summary>
    ''' Get/set the port to be accessed.
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Property Port() As Integer
        Get
            Return m_port
        End Get
        Set(ByVal value As Integer)
            m_port = value
        End Set
    End Property

    ''' <summary>
    ''' Default class constructor.
    ''' </summary>
    ''' <param name="name"></param>
    ''' <param name="address"></param>
    ''' <param name="port"></param>
    ''' <remarks></remarks>
    Public Sub New(ByVal name As String, ByVal address As String, ByVal port As Integer)
        m_name = name
        m_address = address
        m_port = port
    End Sub

End Class
